All Classes and Interfaces
Class
Description
ParameterValueMapper backed by a ConversionService.Information describing an operation method on an endpoint method.
Filter that rebuilds the body for form urlencoded posts.
Filter that creates RFC 7239 compliant Forwarded headers to send to downstream
services.
Deprecated.
Once Spring Retry is no longer being maintained, we will remove this class
and move the logic to @link GatewayRetryFilterFunctions.
A MultipartResolver that does not resolve if the current request is a Gateway request.
BeanDefinitionRegistrar that registers a RouterFunctionHolder and a
DelegatingRouterFunction.
Simply holds the composite gateway RouterFunction.
A
BeanFactoryInitializationAotProcessor responsible for registering reflection
hints for Gateway MVC beans.Deprecated.
This filter is based on
Spring Retry which has
been placed in maintenance-only mode.
AutoConfiguration for Spring Cloud Gateway MVC server.
The context for the
invocation of an operation.RuntimeException thrown when an endpoint invocation does not contain required
parameters.Resolver for an argument of an
.
invalid reference
Operation
Interface to perform an operation invocation.
Allows additional functionality to be applied to an
OperationInvoker.A single operation parameter.
A collection of
operation parameters.A
ParameterMappingException is thrown when a failure occurs during
operation parameter mapping.Maps parameter values to the required type when invoking an endpoint.
An
OperationInvoker that invokes an operation using reflection.Factory bean for the creation of a RouterFunctionHolder, that may have refresh scope.
Converter for converting String to ZonedDateTime.